<?php
/***************************************************************************
 *                          lang_faq.php [Swedish]
 *                            -------------------
 *   begin                : Wednesday Oct 3, 2001
 *   copyright            : (C) 2001 The phpBB Group
 *   email                : support@phpbb.com
 *
 *   $Id: lang_faq.php,v 1.1.2.1 2002/05/19 17:32:51 psotfx Exp $
 *
 *
 ***************************************************************************/

/***************************************************************************
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 ***************************************************************************/

//  *************************************
//  First, original Swedish translation by:
//	
//	Marcus Svensson
//      admin@world-of-war.com
//      http://www.world-of-war.com
//	-------------------------------------
// 	Janke Rnnblom
//	jan-ake.ronnblom@skeria.skelleftea.se
//	-------------------------------------
//	Bruce
//	bruce@webway.se
//	-------------------------------------
//      Jakob Persson
//      jakob.persson@iname.com
//      http://www.jakob-persson.com
//
//  *************************************
//  Maintained and kept up-to-date by:
//  
//  Jonathan Gulbrandsen (Virtuality)
//  virtuality@carlssonplanet.com
//  http://www.carlssonplanet.com
//  *************************************
//

// CONTRIBUTORS:
//	 Add your details here if wanted, e.g. Name, username, email address, website
// XXXX-XX-XX  Orginal translation to Swedish by Marcus Svensson, Janke Rnnblom, Bruce and Jakob Persson
// 2003-07-31  Virtuality aka Jonathan Gulbrandsen (virtuality@carlssonplanet.com)        - updated to 2.0.5
// 2003-08-12  Virtuality aka Jonathan Gulbrandsen (virtuality@carlssonplanet.com)        - updated to 2.0.6
// 2005-01-31  Virtuality aka Jonathan Gulbrandsen (virtuality@carlssonplanet.com)        - updated to 2.0.11

// 
// To add an entry to your FAQ simply add a line to this file in this format:
// $faq[] = array("question", "answer");
// If you want to separate a section enter $faq[] = array("--","Block heading goes here if wanted");
// Links will be created automatically
//
// DO NOT forget the ; at the end of the line.
// Do NOT put double quotes (") in your FAQ entries, if you absolutely must then escape them ie. \"something\";
//
// The FAQ items will appear on the FAQ page in the same order they are listed in this file
//
 
  
$faq[] = array("--","Inloggnings- och registreringsproblem");
$faq[] = array("Varfr kan jag inte logga in?", "Har du registrerat dig? Du mste registrera dig fr att kunna logga in. Har du blivit avstngd frn forumet (i s fall visas ett meddelande)? Om s r fallet br du kontakta webbmastern eller forum administratren fr att f reda p varfr. Om du har registrerat dig och inte r avstngd men nd inte kan logga in kontrollera d ditt anvndarnamn och lsenord. Oftast r det problemet, om inte s kontakta forum administratren.");
$faq[] = array("Varfr mste jag registera mig?", "Det r inte skert att du behver, det r upp till forum administratren om du behver registrera dig fr att skriva ett meddelande. Dock s ger registreringen dig ytterligare funktioner som inte r tillgngliga fr gster, till exempel avatar bilder, personliga meddelanden, e-post till andra anvndare, prenumeration av anvndargrupper, etc. Det tar endast ngra sekunder att registrera sig s det r att rekommendera.");
$faq[] = array("Varfr blir jag automatiskt utloggad?", "Om du inte kryssar i <i>Logga in mig automatiskt</i> nr jag besker forumet s kommer du endast att vara inloggad under en begrnsad tid. Det fr att frhindra att ngon missbrukar ditt konto. Fr att frbli inloggad kryssa i rutan vid inloggningen, det r dock inte att rekommendera om du lser forumet frn en offentlig dator, ssom bibliotek, Internetcaf, skola, etc.");
$faq[] = array("Hur hindrar jag att mitt anvndarnamn visas p Vem r Online-listan?", "I din profil finns en instllning <i>Dlj din online status</i>, om du ndrar instllningen till <i>p</i>, s syns du bara fr forum-administratrer och dig sjlv. Du kommer att rknas som en dold anvndare.");
$faq[] = array("Jag har glmt mitt lsenord!", "Ingen panik. ven om ditt lsenord inte kan lsas s kan det ndras. Fr att gra detta g tillbaka till login sidan och klicka p <u>Jag har glmt mitt lsenord</u>, flj instruktioner och du kommer att vara tillbaka online p nolltid.");
$faq[] = array("Jag har registrerat mig men jag kan inte logga in!", "Kontrollera frst att du anvnder rtt anvndarnamn och lsenord. Om de r okej s kan tv saker intrffat. Om COPPA std r aktiverat och om du klickat p <u>Jag r under 13 r</u> nr du registrerat dig s mste du flja instruktionerna du ftt. Om s inte r fallet s kanske ditt konto behver aktiveras? Vissa forum krver att alla nyregisteringar mste aktiveras, antingen av dig sjlv eller av administratren innan du kan logga in. Nr du registrerade dig s str det angivet om du mste aktivera kontot. Om du ftt ett e-post meddelande s flj instruktionerna i det, om inte s r du sker p angett en korrekt e-post addresS? En anledning till att man anvnder aktivering r att minska mjligheten fr <i>okunniga</i> anvndare att missbruka forumet anonymt. Om du r sker p att e-post adressen r giltig s kontakta administratren fr forumet.");
$faq[] = array("Jag har registrerat mig tidigare men nu kan jag inte logga in lngre?!", "De troligaste anledningarna till detta r; du har angett ett felaktig anvndarnamn eller lsenord (ls e-postmeddelandet du fick nr du frst registrerade dig) eller s har administratren raderat ditt konto av ngon anledning. Om det r det andra fallet s kanske du inte har skrivit ngot inlgg? Det r normalt fr forum att ibland radera anvndare som inte har skrivit ngot fr att minska storleken p databasen. Frsk registrera dig igen och skriv ett inlgg i en diskussion.");


$faq[] = array("--","Anvndarpreferenser och instllningar");
$faq[] = array("Hur ndrar jag mina instllningar?", "Alla dina instllningar (om du har registrerat dig) r lagrade i databasen. Fr att ndra dom klicka p Profillnken (visas oftast hgst upp p sidan). Detta lter dig ndra alla dina instllningar.");
$faq[] = array("Tiden r inte rtt!", "Tiden r med all skerhet korrekt, dock vad du kanske ser r tid som visas i en annan tidszon r den du befinner dig i. Om s r fallet s br du ndra dina instllningar fr att tidszonen ska stmma verens med din plats, tex. Stockholm, Helsingfors, New York, Sydney, etc. Notera att fr att ndra tidszonen, och de flesta instllningarna, s mste du vara registrerad. S om du inte har registrerat dig s r det god tid att gra det nu, om du ursktar ordvitsen!");
$faq[] = array("Jag har ndrat tidszonen och tiden r fortfarande fel!", "Om du r sker p att du har satt tidszonen korrekt och tiden fortfarande r felaktig s r \"Daylight Savings Time\" (eller sommartid som det kallas i Sverige och i andra lnder) det mest troliga svaret. Forumet r inte designat fr att hantera frndringarna mellan vinter och sommartid s under sommar mnaderna kan tiden vara en timme fel.");
$faq[] = array("Mitt sprk finns inte i listan!", "Det mest troliga sklet fr detta r att antingen s har administratren inte installerat ditt sprk eller s har inte ngon versatt forumet till ditt sprk. Frga administratrerna om de inte kan installera det sprk du behver och om det inte finns s tag grna chansen och skapa en ny versttning. Mer information finns p phpBB websiten (se lnken lngst ner p sidorna)");
$faq[] = array("Hur visar jag en bild under mitt anvndarnamn?", "Det kan finnas tv bilder under anvndarnamnet nr man tittar i en trd. Den frst r en bild som r associerat med din rang, oftast r bilderna i form av stjrnor eller block som visar hur mnga inlgg du har skrivit eller din status i forumet. Under den kan det finns en bild som r knt som en avatar, denna r i allmnhet unik eller personlig fr varje anvndare. Det r upp till forum-administratren att tillta avatarer och de kan ven vlja p vilket stt avatarer grs tillgngliga fr anvndaren. Om du inte kan anvnda avatarer i forumet s r det ett beslut av administratrerna, och du kan frga dom om deras skl till detta (vi r skra p att de r bra!)");
$faq[] = array("Hur ndrar jag min rank?", "I normala fall kan du inte ndra din rang direkt (rang str under ditt anvndarnamn i mnen och i din profil beroende p vilken stil som valts). De flesta forumen anvnder rang fr att indikera antalet inlg du har skrivet och fr att identifiera vissa anvndare, e.g. moderatorer och administratrer kan ha en speciell rang. Frsk att inte missbruka forumet genom att skriva ondiga inlgg bara fr att ka din rang, administratrerna kommer i sfall att helt enkelt snka ditt antal inlgg.");
$faq[] = array("Nr jag klickar p e-postlnken till en anvndare s vill forumet att jag loggar in?", "Tyvrr kan bara registrerade anvndaren skicka e-post till andra anvndare vid det inbyggda e-post formulret (om administratrerna har aktivera denna finess). Detta r fr att frhindra missbruk av e-postsystemet av anonyma anvndare.");


$faq[] = array("--","Problem med inlgg");
$faq[] = array("Hur skriver jag ett meddelande i ett forum?", "Enkelt, klicka p den relevanta knappen antingen p forum eller mnes sidan. Det r mjligt att du behver registrera dig innan du kan skriva ett meddelande, de optioner du kan gra visas lngst ner p forum och mnes sidan (<i>Du kan skapa ett nytt meddelande, Du kan rsta i omrstningar, etc<i> listan)");
$faq[] = array("Hur ndrar jag eller raderar jag ett inlgg?", "Svida du inte r administratr eller moderator kan du bara redigera och radera din egna inlgg. Du kan redigera ett meddelande (ibland bara inom en begrnsad tid efter det att det skrevs) genom att klicka p <i>redigera</i> knappen fr det relevanta meddelandet. Om ngon redan har besvarat meddelandet kommer det att finnas en frklarande text under meddelandet som talar om det har redigerats, detta visar hur mnga gnger meddelandet har blivit redigerat. Detta syns enbart om ingen har svarat, det syns inte heller om en moderator eller administratr redigerar meddelandet (dock br de lmna ett meddelande som talar om vad de har ndrat och varfr). Notera att normala anvndare inte kan radera meddelanden nr ngon svarat p det.");
$faq[] = array("Hur lgger jag till en signatur till mitt meddelande?", "Fr att lgga till en signatur till ett meddelande mste du frst skapa en, detta gr du via din profil. Nr du vl har skapat din signatur kan du kryssa i <i>Lgg till signatur</i> nr du skapar meddelandet fr att lgga til din signatur. Du kan ocks lgga till en signatur automatiskt till alla din meddelanden genom att stlla in det i din profil (du kan fortfarande hindra din signatur frn att lggas till genom att kryss av lgg till signatur rutan nr du skapar meddelandet)");
$faq[] = array("Hur skapar jag en omrstning?", "Att skapa en omrstning r enkelt, nr du skapar ett nytt mne (eller redigerar det frsta meddelandet i ett mne) s ska det finnas ett <i>Lgg till omrstning</i> forumlr under nytt meddelande boxen (om du inte kan se detta s har du frmodligen inte rttigheter att skapa nya omrstningar). Du br ange en titel fr omrstningen och minst tv val (fr att skapa en valmjlighet ange frgan och klicka p <i>Lgg till nytt val</i> knappen. Du kan ocks ange en tidsbegrsning fr omrstningen, 0 r ondligt. Det finns en begrsning p hur mnga olika valmjligheter du kan ha, detta bestms av forum-administratren.");
$faq[] = array("Hur ndrar jag en omrstning?", "Meddelanden och omrstningar kan enbart redigeras av den som skapat dom, eller av moderatorer eller administratrer. Fr att redigera en omrstning klicka p frsta meddelandet i mnet (denna r alltid associerad med omrstningen). Om ingen har rstat s kan anvndare radera omrstningen eller redigera valmjligheterna. Dock om ngon har rstat s kan bara moderatorer eller administratrer redigera eller radera omrstningen. Detta fr att frhindra folk att rigga omrstningar genom att ndra valmjligheter nr folk redan har rstat.");
$faq[] = array("Varfr kan jag inte komma in i ett forum?", "Vissa forum kan vara begrnsad till vissa anvndare eller grupper. Fr att lista, lsa, skriva, etc s mste du ha en speciell auktorisation, enbart forum moderatoren eller forum-administratrer kan ge denna rttigheter, s du mste kontakta dom.");
$faq[] = array("Varfr kan jag inte rsta i omrstningar?", "Enbart registrerad anvndare kan rsta i omrstningar (fr att hindra fejkade resultat). Om du r registrerad och du fortfarande inte kan rsta s har du frmodligen inte rttigheter till att rsta.");


$faq[] = array("--","Formatteringar och rubrik/mnes typer");
$faq[] = array("Vad r BBCode?", "BBCode r en speciell implementation av HTML, om du kan anvnda BBCode bestms av administratren (du kan ocks hindra anvndningen av BBCode i det aktuella meddelandet nr du skapar det). BBCode i sig r snarlikt HTML, taggar r omgrdade/inneslutna i hakparanteser [ och ] isf &lt; och &gt; och BBCode ger strre kontroll ver hur vad och hur ngonting visas. Fr mera information om BBCode titta i guiden som kan ns frn nytt meddelande sidan.");
$faq[] = array("Kan jag anvnda HTML?", "Det beror p om administratren tillter dig, de har total kontroll ver det. Om det r tilltet kommer du att finna att det bara r vissa taggar som fungerar. Detta r en <i>skerhets</i> tgrd fr att hindra folk frn att missbruka forumet genom att anvnda taggar som kan frstra designen eller skapa andra problem. Om HTLM r tillt s kan du hindra det i det aktuella meddelandet nr du skapar det.");
$faq[] = array("Vad r smileys?", "Smileys, eller Emoticons r sm grafiska bilder som kan anvndas fr att uttrycka ngon typ av knsla via en frkortning, e.g. :) betyder lycklig, :( betyder ledsen. Hela listan av emoticons kan du hitta via nytt meddelande formulret. Frsk att inte veranvnda smileys, de kan fort f ett meddelande att bli olsbart och en moderator kan bestmma sig fr att redigera bort dem frn meddelandet eller radera hela meddelandet.");
$faq[] = array("Kan jag posta bilder?", "Bilder kan visas i ditt meddelande. Dock finns det fr tillfllet ingen funktion fr att ladda upp bilder till forumet. Drfr mste du lnka till en bild som lagras p en publik webserver, t.ex. <pre>http://www.some-unknown-place.net/my-picture.gif</pre>. Du kan inte lnka till bilder som lagras p din lokala PC (svida den inte r en publikt tillgnglig server) eller till bilder som lagras bakom auktoriserings mekanismer, e.g. hotmail eller yahoo mailkonto, lsenordsskyddade siter, etc. Fr att visa en bild s anvnd antingen BBCode [img] taggen eller motsvarande HTML (om det tillts).");
$faq[] = array("Vad r Viktiga mnen/meddelanden?", "Viktiga meddelande innehller oftast viktig information och du br lsa dom s fort som mjligt. Viktiga meddelande syns hgst upp p varje sida i det forum som de skrivs. Om du kan eller inte kan skriva viktiga meddelande beror p vilka rttigheter som behvs, vilka styrs av administratrerna.");
$faq[] = array("Vad r Klistrade mnen/meddelanden?", "Klistrade mnen syns under viktiga meddelande och enbart p frsta sidan. De innehller ofta viktig information s du br lsa dom nr det r mjligt. Ssom med viktiga meddelande s r det administratrerna som bestmmer vilka rttigheter som behvs fr att kunna skriva Klistrade mnen.");
$faq[] = array("Vad r lsta mnen/meddelanden?", "Lsta mnen skapas av antingen forum moderatorerna eller av forum-administratrerna. Du kan inte besvara ett lst mne och om den innehller en omrstning s stoppas denna automatiskt. mnen kan lsas av mnga skl.");


$faq[] = array("--","Anvndarniver och grupper");
$faq[] = array("Vad r administratrer?", "Administratrer r personer som har den absolut hgst nivn av kontroll ver hela forumet. Dessa personer kan kontrollera alla aspekter av forumets drift vilket inkluderar att stta rttigheter, bannlysa anvndare, skapa anvndargrupper eller moderatorer, etc. De har ocks fulla moderator rttigheter i alla forum.");
$faq[] = array("Vad r moderatorer?", "Moderatorer r individer (eller grupper av individer) vilkas jobb det r att skta om de dagliga aktiviterna i forumet. De har rttigheter att redigera eller radera meddelanden och lsa, lsa upp, flytta, radera och dela rubriker i forumet som de modererar. Generellt s r moderaratorer dr fr att hindra personer frn att <i>komma ifrn mnet<i> eller att skriva missbrukande eller ansttligt material.</i>");
$faq[] = array("Vad r anvndargrupper?", "Anvndargrupper r ett stt som forum-administratrerna anvnder fr att gruppera anvndare. Varje anvndare kan tillhra flera grupper (detta skiljer frn de flesta andra forumen) och varje grupp kan tilldelas individuella rttigheter. Detta gr det enkelt fr administratrer att ange flera anvndare som moderatorer fr ett forum eller ge dom tkomst till ett privat forum, etc.");
$faq[] = array("Hur gr jag med i en anvndargrupp?", "Fr att ansluta dig till en anvndargrupp s klicka p anvndargrupplnken i sidhuvudet (beroende p designmallen som anvnds), du kan d visa alla anvndargrupper. Inte alla grupper r <i>ppna</i>, vissa r stngda och vissa kan ven vara dolda. Om gruppen r ppen kan du anska om att f bli medlem genom att klicka p lmplig knapp. Anvndargruppens moderator mste d i sin tur bevilja din anskan och kan ven frga varfr du vill bli medlem. Och tjata inte p moderatorerna om de nekar dig de har skerligen sina skl.");
$faq[] = array("Hur blir jag moderator fr en anvndargrupp?", "Anvndargrupper skapas initialt av administratrerna och de utser ocks gruppmoderator. Om du r intresserad av att skapa en anvndargrupp s r din frsta kontakt ngon av administratrerna. Skicka ett personligt meddelande till de.");


$faq[] = array("--","Personliga meddelanden");
$faq[] = array("Jag kan inte skicka personliga meddelanden!", "Det finns tre skl till detta; du r inte registrerad och/eller du har inte logga in, administratren har inaktiverat personliga meddelanden fr hela forumet eller administratrern har stoppat dig frn att skicka meddelanden. Om det r det senare fallet s frga administratren varfr.");
$faq[] = array("Jag fr onskade personliga meddelanden!", "I framtiden kommer vi att lgga till en ignoreralista till det personliga meddelandesystemet. Om du fortstter att f onskade meddelanden s prata med en administratr, de har mjligheter att stoppa en anvndare frn att skicka personliga meddelanden verhuvudtaget.");
$faq[] = array("Jag har ftt spam eller ansttliga e-postmeddelanden frn ngon p detta forum!", "Vi r ledsna att hra detta. E-postforumlret i forumet innehller skydd fr att frska att spra anvndare som skickar sdana e-postmeddelanden. Du br e-posta administratrerna p forumet och bifoga en full kopia av e-postmeddelande du fick och det r mycket viktigt att du bifogar e-posthuvudet (detta innehller detaljerna om vilken anvndare som skickat e-postmeddelandet). Administratrerna kan drefter vidta tgrder.");

//
// These entries should remain in all languages and for all modifications
//
$faq[] = array("--","phpBB 2 Issues");
$faq[] = array("Who wrote this bulletin board?", "This software (in its unmodified form) is produced, released and is copyright  <a href=\"http://www.phpbb.com/\" target=\"_blank\">phpBB Group</a>. It is made available under the GNU General Public Licence and may be freely distributed, see link for more details");
$faq[] = array("Why isn't X feature available?", "This software was written by and licensed through phpBB Group. If you believe a feature needs to be added then please visit the phpbb.com website and see what phpBB Group have to say. Please do not post feature requests to the board at phpbb.com, the Group uses sourceforge to handle tasking of new features. Please read through the forums and see what, if any, our position may already be for a feature and then follow the procedure given there.");
$faq[] = array("Who do I contact about abusive and/or legal matters related to this board?", "You should contact the administrator of this board. If you cannot find who this you should first contact one of the forum moderators and ask them who you should in turn contact. If still get no response you should contact the owner of the domain (do a whois lookup) or, if this is running on a free service (e.g. yahoo, free.fr, f2s.com, etc.), the management or abuse department of that service. Please note that phpBB Group has absolutely no control and cannot in any way be held liable over how, where or by whom this board is used. It is absolutely pointless contacting phpBB Group in relation to any legal (cease and desist, liable, defamatory comment, etc.) matter not directly related to the phpbb.com website or the discrete software of phpBB itself. If you do email phpBB Group about any third party use of this software then you should expect a terse response or no response at all.");

//
// This ends the FAQ entries
//

?>